@@ -4,14 +4,14 @@ BEGIN {
   $Class::MOP::Method::Meta::AUTHORITY = 'cpan:STEVAN';
 }
 {
-  $Class::MOP::Method::Meta::VERSION = '2.0302'; # TRIAL
+  $Class::MOP::Method::Meta::VERSION = '2.0500'; # TRIAL
 }
 
 use strict;
 use warnings;
 
 use Carp         'confess';
-use Scalar::Util 'blessed';
+use Scalar::Util 'blessed', 'weaken';
 
 use constant DEBUG_NO_META => $ENV{DEBUG_NO_META} ? 1 : 0;
 
@@ -26,6 +26,8 @@ sub _is_caller_mop_internal {
 sub _generate_meta_method {
     my $method_self = shift;
     my $metaclass   = shift;
+    weaken($metaclass);
+
     sub {
         # this will be compiled out if the env var wasn't set
         if (DEBUG_NO_META) {
@@ -93,7 +95,7 @@ Class::MOP::Method::Meta - Method Meta Object for C<meta> methods
 
 =head1 VERSION
 
-version 2.0302
+version 2.0500
 
 =head1 DESCRIPTION
 
@@ -119,7 +121,7 @@ Moose is maintained by the Moose Cabal, along with the help of many contributors
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Infinity Interactive, Inc..
+This software is copyright (c) 2012 by Infinity Interactive, Inc..
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
